@@ -26,20 +26,18 @@ sits_to_csv <- function(data, file) {
     # set caller to show in errors
     .check_set_caller("sits_metadata_to_csv")
 
+    # check the samples are valid
+    .check_samples(data)
+
     .check_that(
         x = suppressWarnings(file.create(file)),
         msg = "file is not writable"
     )
 
-    csv_columns <- c("longitude", "latitude", "start_date", "end_date", "label")
-
+    csv_columns <- .conf("df_sample_columns")
     # select the parts of the tibble to be saved
     csv <- dplyr::select(data, dplyr::all_of(csv_columns))
 
-    .check_that(
-        x = nrow(csv) > 0,
-        msg = "invalid csv file"
-    )
     n_rows_csv <- nrow(csv)
     # create a column with the id
     id <- tibble::tibble(id = 1:n_rows_csv)
@@ -50,32 +48,12 @@ sits_to_csv <- function(data, file) {
     # write the CSV file
     utils::write.csv(csv, file, row.names = FALSE, quote = FALSE)
 }
-#' @title Check if a CSV tibble is valid
-#' @name  .sits_csv_check
-#' @keywords internal
-#'
-#' @param  csv       Tibble read from a CSV file
-#' @return           Does the CSV file contain the columns needed by sits?
-#'
-.sits_csv_check <- function(csv) {
 
-    # set caller to show in errors
-    .check_set_caller(".sits_csv_check")
-
-    # check if required col names are available
-    .check_chr_contains(
-        x = colnames(csv),
-        contains = .config_get("df_sample_columns"),
-        discriminator = "all_of",
-        msg = "invalid csv file"
-    )
-
-    return(invisible(TRUE))
-}
 #' @title Transform a shapefile into a samples file
 #' @name .sits_get_samples_from_csv
 #' @author Gilberto Camara
 #' @keywords internal
+#' @noRd
 #' @param csv_file        CSV that describes the data to be retrieved.
 #' @return                A tibble with information the samples to be retrieved
 #'
@@ -85,17 +63,17 @@ sits_to_csv <- function(data, file) {
     samples <- tibble::as_tibble(utils::read.csv(csv_file))
 
     # pre-condition - check if CSV file is correct
-    .sits_csv_check(samples)
+    .check_csv(samples)
 
     # select valid columns
     samples <- dplyr::select(
         samples,
-        dplyr::all_of(.config_get("df_sample_columns"))
+        .conf("df_sample_columns")
     )
-
+    # transform to date
     samples <- dplyr::mutate(samples,
-        start_date = as.Date(.data[["start_date"]]),
-        end_date = as.Date(.data[["end_date"]])
+                             start_date = as.Date(.data[["start_date"]]),
+                             end_date = as.Date(.data[["end_date"]])
     )
 
     class(samples) <- c("sits", class(samples))
