@@ -231,7 +231,7 @@
 #'     usgs_cube <- sits_cube(
 #'         source = "USGS",
 #'         collection = "landsat-c2l2-sr",
-#'         bands = c("B04", "CLOUD"),
+#'         bands = c("GREEN", "CLOUD"),
 #'         roi = c(
 #'             "xmin" = -50.379,
 #'             "ymin" = -10.1573,
@@ -242,7 +242,6 @@
 #'         end_date = "2019-10-28"
 #'     )
 #'
-#'
 #'     # -- Creating Sentinel cube from MPC"
 #'     s2_cube <- sits_cube(
 #'         source = "MPC",
@@ -307,7 +306,8 @@ sits_cube.stac_cube <- function(source,
                                 roi = NULL,
                                 start_date = NULL,
                                 end_date = NULL,
-                                platform = NULL) {
+                                platform = NULL,
+                                progress = TRUE) {
     dots <- list(...)
 
     # deal with wrong parameter "band"
@@ -322,20 +322,20 @@ sits_cube.stac_cube <- function(source,
         tiles <- as.character(dots[["tile"]])
     }
 
-    # ensuring that duplicate tiles will not be propagated
-    if (!is.null(tiles)) {
+    # Ensures that only a spatial filter is informed
+    if (.has(roi) && .has(tiles)) {
+        stop("It is not possible to search with roi and tiles.",
+             "Please provide only roi or tiles.")
+    }
+
+    # Ensures that there are no duplicate tiles
+    if (.has(tiles)) {
         tiles <- unique(tiles)
     }
 
-    if (!is.null(roi) && !is.null(tiles)) {
-        stop(paste(
-            "It is not possible to search with roi and tiles.",
-            "Please provide only roi or tiles."
-        ))
-    }
-    # check if roi is provided correctly
-    if (!purrr::is_null(roi)) {
-        roi <- .sits_parse_roi_cube(roi)
+    # Converts provided roi to sf
+    if (.has(roi)) {
+        roi <- .roi_as_sf(roi)
     }
 
     # source is upper case
@@ -370,7 +370,7 @@ sits_cube.stac_cube <- function(source,
     }
 
     # Pre-condition - checks if the bands are supported by the collection
-    .config_check_bands(
+    .conf_check_bands(
         source = source,
         collection = collection,
         bands = bands
@@ -392,10 +392,11 @@ sits_cube.stac_cube <- function(source,
         collection = collection,
         bands = bands,
         tiles = tiles,
-        roi_sf = roi,
+        roi = roi,
         start_date = start_date,
         end_date = end_date,
-        platform = platform, ...
+        platform = platform,
+        progress = progress, ...
     )
 }
 
@@ -405,6 +406,7 @@ sits_cube.stac_cube <- function(source,
 sits_cube.local_cube <- function(source,
                                  collection,
                                  data_dir, ...,
+                                 tiles = NULL,
                                  bands = NULL,
                                  start_date = NULL,
                                  end_date = NULL,
@@ -418,8 +420,6 @@ sits_cube.local_cube <- function(source,
     # precondition - data directory must be provided
     .check_file(x = data_dir, msg = "'data_dir' parameter must be provided.")
 
-    # check documentation mode
-    progress <- .check_documentation(progress)
     # precondition - check source and collection
     .source_check(source = source)
     .source_collection_check(source = source, collection = collection)
@@ -428,7 +428,7 @@ sits_cube.local_cube <- function(source,
 
     # deal with wrong parameter "band" in dots
     if ("band" %in% names(dots) && missing(bands)) {
-        message("please use bands instead of band as parameter")
+        message("please, use 'bands' instead of 'band' as parameter")
         bands <- as.character(dots[["band"]])
     }
 
@@ -439,6 +439,7 @@ sits_cube.local_cube <- function(source,
         data_dir = data_dir,
         parse_info = parse_info,
         delim = delim,
+        tiles = tiles,
         bands = bands,
         labels = labels,
         start_date = start_date,
