@@ -1,4 +1,5 @@
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_check_package.terra <- function() {
 
@@ -14,18 +15,21 @@
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_data_type.terra <- function(data_type, ...) {
     return(data_type)
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_resampling.terra <- function(method, ...) {
     return(method)
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_get_values.terra <- function(r_obj, ...) {
 
@@ -38,6 +42,7 @@
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_set_values.terra <- function(r_obj, values, ...) {
     terra::values(x = r_obj) <- as.matrix(values)
@@ -46,12 +51,36 @@
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_extract.terra <- function(r_obj, xy, ...) {
     terra::extract(x = r_obj, y = xy, ...)
 }
 
 #' @keywords internal
+#' @noRd
+#' @export
+.raster_ext_as_sf.terra <- function(r_obj) {
+    suppressWarnings(
+        sf::st_as_sf(terra::as.polygons(
+            x = terra::ext(r_obj),
+            crs = terra::crs(r_obj)
+        ))
+    )
+}
+
+#' @keywords internal
+#' @noRd
+#' @export
+.raster_file_blocksize.terra <- function(r_obj) {
+        block_size <- c(terra::fileBlocksize(r_obj))
+        names(block_size) <- c("nrows", "ncols")
+
+        return(block_size)
+}
+
+#' @keywords internal
+#' @noRd
 #' @export
 .raster_rast.terra <- function(r_obj, nlayers = 1, ...) {
     suppressWarnings(
@@ -60,20 +89,20 @@
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_open_rast.terra <- function(file, ...) {
     suppressWarnings(
-        terra::rast(x = file, ...)
+        terra::rast(x = path.expand(file), ...)
     )
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_write_rast.terra <- function(r_obj,
                                      file,
-                                     format,
                                      data_type,
-                                     gdal_options,
                                      overwrite, ...,
                                      missing_value = NA) {
 
@@ -83,11 +112,11 @@
     suppressWarnings(
         terra::writeRaster(
             x = r_obj,
-            filename = file,
+            filename = path.expand(file),
             wopt = list(
-                filetype = format,
+                filetype = "GTiff",
                 datatype = data_type,
-                gdal = gdal_options
+                gdal = .conf("gdal_creation_options")
             ),
             NAflag = missing_value,
             overwrite = overwrite, ...
@@ -104,6 +133,7 @@
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_new_rast.terra <- function(nrows,
                                    ncols,
@@ -119,6 +149,9 @@
     # prepare resolution
     resolution <- c(xres, yres)
 
+    # prepare crs
+    if (is.numeric(crs)) crs <- paste0("EPSG:", crs)
+
     if (is.null(resolution)) {
 
         # create a raster object
@@ -154,117 +187,71 @@
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
-.raster_open_stack.terra <- function(files, ...) {
-    suppressWarnings(
-        terra::rast(files, ...)
-    )
-}
-
-#' @keywords internal
-#' @export
-.raster_read_stack.terra <- function(files, ...,
-                                     block = NULL,
-                                     out_size = NULL,
-                                     method = "bilinear") {
-
-    # convert the method to the actual package
-    method <- .raster_resampling(method = method)
+.raster_read_rast.terra <- function(files, ..., block = NULL) {
 
     # create raster objects
-    r_obj <- .raster_open_stack.terra(files = files, ...)
+    r_obj <- .raster_open_rast.terra(file = path.expand(files), ...)
 
-    # get raster size
-    in_size <- .raster_size(r_obj)
-
-    # do resample
-    if (!is.null(out_size) &&
-        (in_size[["nrows"]] != out_size[["nrows"]] ||
-            in_size[["ncols"]] != out_size[["ncols"]])) {
-        bbox <- .raster_bbox(r_obj, block = block)
-
-        out_r_obj <- .raster_new_rast(
-            nrows = out_size[["nrows"]],
-            ncols = out_size[["ncols"]],
-            xmin = bbox[["xmin"]],
-            xmax = bbox[["xmax"]],
-            ymin = bbox[["ymin"]],
-            ymax = bbox[["ymax"]],
-            nlayers = .raster_nlayers(r_obj),
-            crs = .raster_crs(r_obj)
-        )
-
-        out_r_obj <- terra::resample(r_obj, out_r_obj, method = method)
+    # start read
+    if (purrr::is_null(block)) {
 
         # read values
-        terra::readStart(out_r_obj)
+        terra::readStart(r_obj)
         values <- terra::readValues(
-            x   = out_r_obj,
+            x   = r_obj,
             mat = TRUE
         )
         # close file descriptor
-        terra::readStop(out_r_obj)
+        terra::readStop(r_obj)
     } else {
 
-        # start read
-        if (purrr::is_null(block)) {
-
-            # read values
-            terra::readStart(r_obj)
-            values <- terra::readValues(
-                x   = r_obj,
-                mat = TRUE
-            )
-            # close file descriptor
-            terra::readStop(r_obj)
-        } else {
-
-            # read values
-            terra::readStart(r_obj)
-            values <- terra::readValues(
-                x      = r_obj,
-                row    = block[["first_row"]],
-                nrows  = block[["nrows"]],
-                col    = block[["first_col"]],
-                ncols  = block[["ncols"]],
-                mat    = TRUE
-            )
-            # close file descriptor
-            terra::readStop(r_obj)
-        }
+        # read values
+        terra::readStart(r_obj)
+        values <- terra::readValues(
+            x = r_obj,
+            row = block[["row"]],
+            nrows = block[["nrows"]],
+            col = block[["col"]],
+            ncols = block[["ncols"]],
+            mat = TRUE
+        )
+        # close file descriptor
+        terra::readStop(r_obj)
     }
 
     return(values)
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_crop.terra <- function(r_obj,
                                file,
-                               format,
                                data_type,
-                               gdal_options,
                                overwrite,
                                block,
                                missing_value = NA) {
-
+    # Update missing_value
+    missing_value <- if (is.null(missing_value)) NA else missing_value
     # obtain coordinates from columns and rows
     # get extent
     xmin <- terra::xFromCol(
         object = r_obj,
-        col    = block[["first_col"]]
+        col = block[["col"]]
     )
     xmax <- terra::xFromCol(
         object = r_obj,
-        col    = block[["first_col"]] + block[["ncols"]] - 1
+        col = block[["col"]] + block[["ncols"]] - 1
     )
     ymax <- terra::yFromRow(
         object = r_obj,
-        row    = block[["first_row"]]
+        row = block[["row"]]
     )
     ymin <- terra::yFromRow(
         object = r_obj,
-        row    = block[["first_row"]] + block[["nrows"]] - 1
+        row = block[["row"]] + block[["nrows"]] - 1
     )
 
     # xmin, xmax, ymin, ymax
@@ -276,11 +263,11 @@
             x = r_obj,
             y = extent,
             snap = "out",
-            filename = file,
+            filename = path.expand(file),
             wopt = list(
-                filetype = format,
+                filetype = "GTiff",
                 datatype = data_type,
-                gdal = gdal_options
+                gdal = .conf("gdal_creation_options")
             ),
             NAflag = missing_value,
             overwrite = overwrite
@@ -289,6 +276,7 @@
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_crop_metadata.terra <- function(r_obj, ...,
                                         block = NULL,
@@ -300,19 +288,19 @@
         # get extent
         xmin <- terra::xFromCol(
             object = r_obj,
-            col    = block[["first_col"]]
+            col = block[["col"]]
         )
         xmax <- terra::xFromCol(
             object = r_obj,
-            col    = block[["first_col"]] + block[["ncols"]] - 1
+            col = block[["col"]] + block[["ncols"]] - 1
         )
         ymax <- terra::yFromRow(
             object = r_obj,
-            row    = block[["first_row"]]
+            row = block[["row"]]
         )
         ymin <- terra::yFromRow(
             object = r_obj,
-            row    = block[["first_row"]] + block[["nrows"]] - 1
+            row = block[["row"]] + block[["nrows"]] - 1
         )
     } else if (!is.null(bbox)) {
         xmin <- bbox[["xmin"]]
@@ -331,30 +319,35 @@
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_nrows.terra <- function(r_obj, ...) {
     terra::nrow(x = r_obj)
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_ncols.terra <- function(r_obj, ...) {
     terra::ncol(x = r_obj)
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_nlayers.terra <- function(r_obj, ...) {
     terra::nlyr(x = r_obj)
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_xmax.terra <- function(r_obj, ...) {
     terra::xmax(x = r_obj)
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_xmin.terra <- function(r_obj, ...) {
     terra::xmin(x = r_obj)
@@ -362,29 +355,34 @@
 
 #' @keywords internal
 #' @export
+#' @noRd
 .raster_ymax.terra <- function(r_obj, ...) {
     terra::ymax(x = r_obj)
 }
 
 #' @keywords internal
 #' @export
+#' @noRd
 .raster_ymin.terra <- function(r_obj, ...) {
     terra::ymin(x = r_obj)
 }
 
 #' @keywords internal
 #' @export
+#' @noRd
 .raster_xres.terra <- function(r_obj, ...) {
     terra::xres(x = r_obj)
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_yres.terra <- function(r_obj, ...) {
     terra::yres(x = r_obj)
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_crs.terra <- function(r_obj, ...) {
     crs <- suppressWarnings(
@@ -392,15 +390,24 @@
     )
 
     if (!is.na(crs[["code"]])) {
-        return(c(crs = paste(crs[["authority"]], crs[["code"]], sep = ":")))
+        return(paste(crs[["authority"]], crs[["code"]], sep = ":"))
     }
 
     suppressWarnings(
-        c(crs = as.character(terra::crs(x = r_obj)))
+        as.character(terra::crs(x = r_obj))
     )
 }
+#' @name .raster_sources.terra
+#' @keywords internal
+#' @noRd
+.raster_sources.terra <- function(r_obj, ...) {
+
+    sources <- terra::sources(r_obj)
+    return(sources)
+}
 
 #' @keywords internal
+#' @noRd
 #' @export
 #'
 .raster_freq.terra <- function(r_obj, ...) {
@@ -408,6 +415,7 @@
 }
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_col.terra <- function(r_obj, x) {
     terra::colFromX(r_obj, x)
@@ -415,7 +423,26 @@
 
 
 #' @keywords internal
+#' @noRd
 #' @export
 .raster_row.terra <- function(r_obj, y) {
     terra::rowFromY(r_obj, y)
 }
+
+#' @keywords internal
+#' @noRd
+#' @export
+.raster_missing_value.terra <- function(file) {
+
+    gdal_info <- terra::describe(path.expand(file))
+    gdal_info <- gdal_info[grepl(pattern = "NoData Value=", x = gdal_info)]
+
+    nodata_value <- gsub(pattern = ".*NoData Value=",
+                         replacement = "",
+                         x = gdal_info)
+
+    if (length(nodata_value) == 0) {
+        return(NULL)
+    }
+    return(as.numeric(nodata_value))
+}
