@@ -3,10 +3,12 @@
 #' @name sits_select
 #' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
 #'
-#' @param data         A sits tibble or data cube.
-#' @param bands        Character vector with the names of the bands.
-#' @param tiles        Character vector with the names of the tiles.
-#' @param ...          Additional parameters to be provided in the select
+#' @param data       A sits tibble or data cube.
+#' @param bands      Character vector with the names of the bands.
+#' @param start_date Character value with the start date band to be filtered.
+#' @param end_date   Character value with the end date band to be filtered.
+#' @param tiles      Character vector with the names of the tiles.
+#' @param ...        Additional parameters to be provided in the select
 #'  function.
 #'
 #' @description Filter only the selected bands from a tibble or a data cube.
@@ -32,7 +34,7 @@ sits_select <- function(data, bands, ...) {
     # set caller to show in errors
     .check_set_caller("sits_select")
     # get the meta-type (sits or cube)
-    data <- .config_data_meta_type(data)
+    data <- .conf_data_meta_type(data)
     UseMethod("sits_select", data)
 }
 
@@ -48,46 +50,37 @@ sits_select.sits <- function(data, bands, ...) {
         within = sits_bands(data),
         msg = "Invalid bands values"
     )
-    data <- .sits_fast_apply(data, col = "time_series", function(x) {
-        dplyr::select(x, dplyr::all_of(c("#..", "Index", bands)))
-    })
+    data <- .sits_select_bands(samples = data, bands = bands)
     return(data)
 }
 
 #' @rdname sits_select
 #'
 #' @export
-sits_select.sits_cube <- function(data, bands, ..., tiles = NULL) {
-
-    # pre-condition - cube
-    .cube_check(data)
-
+sits_select.raster_cube <- function(data,
+                                    bands =  NULL, ...,
+                                    start_date = NULL,
+                                    end_date = NULL,
+                                    tiles = NULL) {
+    # Pre-condition
+    .check_is_raster_cube(data)
+    # Filter bands
+    if (!is.null(bands)) {
+        .check_chr_type(bands)
+        data <- .cube_filter_bands(cube = data, bands = bands)
+    }
+    # Filter dates
+    if (!is.null(start_date) || !is.null(end_date)) {
+        .check_dates_parameter(c(start_date, end_date))
+        data <- .cube_filter_interval(
+            cube = data, start_date = start_date, end_date = end_date
+        )
+    }
+    # Filter tiles
     if (!is.null(tiles)) {
         .check_chr_type(tiles)
-        data <- dplyr::filter(data, .data[["tile"]] %in% !!tiles)
+        data <- .cube_filter_tiles(cube = data, tiles = tiles)
     }
-
-    # filter the file info
-    data <- slider::slide_dfr(data, function(tile) {
-
-        # default bands
-        if (is.null(bands)) {
-            bands <- .cube_bands(tile)
-        }
-
-        # pre-condition - check bands
-        .cube_bands_check(tile, bands = bands)
-
-        db_info <- .file_info(tile)
-        db_info <- dplyr::filter(
-            db_info,
-            .data[["band"]] %in% dplyr::all_of(bands)
-        )
-
-        tile$file_info[[1]] <- db_info
-        return(tile)
-    })
-
     return(data)
 }
 
