@@ -22,27 +22,22 @@
 #'                          to be passed to \code{\link[sits]{sits_classify}}
 #'
 #' @examples
+#' if (sits_run_examples()) {
 #' # Retrieve the set of samples for Mato Grosso (provided by EMBRAPA)
 #' # fit a training model (RFOR model)
-#' samples <- sits_select(samples_modis_4bands, bands = c("NDVI"))
-#' ml_model <- sits_train(samples, sits_rfor(num_trees = 50))
+#' ml_model <- sits_train(samples_modis_ndvi, sits_rfor(num_trees = 50))
 #' # get a point and classify the point with the ml_model
 #' point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
 #' class <- sits_classify(point_ndvi, ml_model)
+#' }
 #' @export
 #'
 sits_train <- function(samples, ml_method = sits_svm()) {
 
     # set caller to show in errors
     .check_set_caller("sits_train")
-
-    # is the input data a valid sits tibble?
-    .check_chr_within(
-        x = "label",
-        within = names(samples),
-        discriminator = "any_of",
-        msg = "input data does not contain a valid sits tibble"
-    )
+    # check if samples are valid
+    .check_samples_train(samples)
 
     # is the train method a function?
     .check_that(
@@ -51,10 +46,10 @@ sits_train <- function(samples, ml_method = sits_svm()) {
     )
 
     .check_that(
-        x = .sits_timeline_check(samples) == TRUE,
+        x = .timeline_check(samples) == TRUE,
         msg = paste0(
             "Samples have different timeline lengths", "\n",
-            "Use.sits_tibble_prune or sits_fix_timeline"
+            "Use .tibble_prune or sits_fix_timeline"
         )
     )
 
