@@ -7,8 +7,8 @@ test_that("EVI generation", {
                 collection = "sentinel-2-l2a",
                 tiles = "20LKP",
                 bands = c("B05", "B8A", "CLOUD"),
-                start_date = as.Date("2019-07-18"),
-                end_date = as.Date("2019-08-30")
+                start_date = "2019-07-18",
+                end_date = "2019-08-30"
             )
         },
         error = function(e) {
@@ -50,17 +50,17 @@ test_that("EVI generation", {
     start_date <- timeline[1]
     end_date <- timeline[length(timeline)]
 
-    expect_true(start_date == as.Date("2019-07-01"))
-    expect_true(end_date == as.Date("2019-08-01"))
+    expect_true(start_date == "2019-07-01")
+    expect_true(end_date == "2019-08-01")
 
-    file_info_b05 <- .file_info(gc_cube_new, bands = "B05")
-    b05_band_1 <- terra::rast(file_info_b05$path[[1]])
+    file_info_b05 <- .fi(gc_cube_new) %>% .fi_filter_bands(bands = "B05")
+    b05_band_1 <- .raster_open_rast(file_info_b05$path[[1]])
 
-    file_info_b8a <- .file_info(gc_cube_new, bands = "B8A")
-    b8a_band_1 <- terra::rast(file_info_b8a$path[[1]])
+    file_info_b8a <- .fi(gc_cube_new) %>% .fi_filter_bands(bands = "B8A")
+    b8a_band_1 <- .raster_open_rast(file_info_b8a$path[[1]])
 
-    file_info_evi2 <- .file_info(gc_cube_new, bands = "EVI2")
-    evi2_band_1 <- terra::rast(file_info_evi2$path[[1]])
+    file_info_evi2 <- .fi(gc_cube_new) %>% .fi_filter_bands(bands = "EVI2")
+    evi2_band_1 <- .raster_open_rast(file_info_evi2$path[[1]])
 
     b05_100 <- as.numeric(b05_band_1[100] / 10000)
     b8a_100 <- as.numeric(b8a_band_1[100] / 10000)
@@ -76,9 +76,9 @@ test_that("EVI generation", {
     evi2_calc_150 <- 2.5 * (b8a_150 - b05_150) / (b8a_150 + 2.4 * b05_150 + 1)
     expect_equal(evi2_150, evi2_calc_150, tolerance = 0.001)
 
-    bbox_cube <- sits_bbox(gc_cube_new, wgs84 = TRUE)
-    lats <- runif(10, min = bbox_cube["ymin"], max = bbox_cube["ymax"])
-    longs <- runif(10, min = bbox_cube["xmin"], max = bbox_cube["xmax"])
+    bbox_cube <- sits_bbox(gc_cube_new, as_crs = "EPSG:4326")
+    lats <- runif(10, min = bbox_cube[["ymin"]], max = bbox_cube[["ymax"]])
+    longs <- runif(10, min = bbox_cube[["xmin"]], max = bbox_cube[["xmax"]])
 
     timeline <- sits_timeline(gc_cube_new)
     start_date <- timeline[1]
@@ -102,7 +102,7 @@ test_that("EVI generation", {
         EVI2_NEW = 2.5 * (B8A - B05) / (B8A + 2.4 * B05 + 1)
     )
 
-    values_evi2 <- sits_time_series(evi_tibble_2)$EVI2
-    values_evi2_new <- sits_time_series(evi_tibble_2)$EVI2_NEW
+    values_evi2 <- .tibble_time_series(evi_tibble_2)$EVI2
+    values_evi2_new <- .tibble_time_series(evi_tibble_2)$EVI2_NEW
     expect_equal(values_evi2, values_evi2_new, tolerance = 0.001)
 })
