@@ -7,7 +7,7 @@ test_that("Reading a LAT/LONG from RASTER", {
                 collection = "MOD13Q1-6",
                 data_dir = data_dir,
                 delim = "_",
-                parse_info = c("X1", "X2", "tile", "band", "date")
+                parse_info = c("X1", "tile", "band", "date")
             )
         },
         error = function(e) {
@@ -24,7 +24,7 @@ test_that("Reading a LAT/LONG from RASTER", {
     point_ndvi <- sits_get_data(raster_cube, samples)
 
     expect_equal(names(point_ndvi)[1], "longitude")
-    expect_true(ncol(sits_time_series(point_ndvi)) == 2)
+    expect_true(ncol(.tibble_time_series(point_ndvi)) == 2)
     expect_true(length(sits_timeline(point_ndvi)) == 23)
 })
 
@@ -37,7 +37,7 @@ test_that("Reading a LAT/LONG from RASTER with crs parameter", {
                 collection = "MOD13Q1-6",
                 data_dir = data_dir,
                 delim = "_",
-                parse_info = c("X1", "X2", "tile", "band", "date")
+                parse_info = c("X1", "tile", "band", "date")
             )
         },
         error = function(e) {
@@ -58,7 +58,7 @@ test_that("Reading a LAT/LONG from RASTER with crs parameter", {
     )
 
     expect_equal(names(point_ndvi)[1], "longitude")
-    expect_true(ncol(sits_time_series(point_ndvi)) == 2)
+    expect_true(ncol(.tibble_time_series(point_ndvi)) == 2)
     expect_true(length(sits_timeline(point_ndvi)) == 23)
 })
 
@@ -71,7 +71,7 @@ test_that("Reading a CSV file from RASTER", {
                 collection = "MOD13Q1-6",
                 data_dir = data_dir,
                 delim = "_",
-                parse_info = c("X1", "X2", "tile", "band", "date")
+                parse_info = c("X1", "tile", "band", "date")
             )
         },
         error = function(e) {
@@ -100,7 +100,7 @@ test_that("Reading a CSV file from RASTER", {
     expect_true("Forest" %in% sits_labels(points_poly))
     expect_equal(names(points_poly)[1], "longitude")
     expect_equal(length(names(points_poly)), 7)
-    expect_true(ncol(sits_time_series(points_poly)) == 2)
+    expect_true(ncol(.tibble_time_series(points_poly)) == 2)
     expect_true(length(sits_timeline(points_poly)) == 23)
 
     points_df <- sits_get_data(raster_cube,
@@ -111,7 +111,7 @@ test_that("Reading a CSV file from RASTER", {
     expect_true("Forest" %in% sits_labels(points_df))
     expect_equal(names(points_df)[1], "longitude")
     expect_equal(length(names(points_df)), 7)
-    expect_true(ncol(sits_time_series(points_df)) == 2)
+    expect_true(ncol(.tibble_time_series(points_df)) == 2)
     expect_true(length(sits_timeline(points_df)) == 23)
 })
 
@@ -124,7 +124,7 @@ test_that("Reading a CSV file from RASTER with crs parameter", {
                 collection = "MOD13Q1-6",
                 data_dir = data_dir,
                 delim = "_",
-                parse_info = c("X1", "X2", "tile", "band", "date")
+                parse_info = c("X1", "tile", "band", "date")
             )
         },
         error = function(e) {
@@ -166,7 +166,7 @@ test_that("Reading a CSV file from RASTER with crs parameter", {
     expect_true("Forest" %in% sits_labels(points_df))
     expect_equal(names(points_df)[1], "longitude")
     expect_equal(length(names(points_df)), 7)
-    expect_true(ncol(sits_time_series(points_df)) == 2)
+    expect_true(ncol(.tibble_time_series(points_df)) == 2)
     expect_true(length(sits_timeline(points_df)) == 23)
 })
 
@@ -179,7 +179,7 @@ test_that("Reading a SHP file from RASTER", {
                 collection = "MOD13Q1-6",
                 data_dir = data_dir,
                 delim = "_",
-                parse_info = c("X1", "X2", "tile", "band", "date")
+                parse_info = c("X1", "tile", "band", "date")
             )
         },
         error = function(e) {
@@ -190,25 +190,21 @@ test_that("Reading a SHP file from RASTER", {
     testthat::skip_if(purrr::is_null(raster_cube),
                       message = "LOCAL cube was not found"
     )
-
-    poly_lst <-  list(
-        list(
+    polygons_sf <- rbind(
+        sf::st_as_sf(sf::st_as_sfc(sf::st_bbox(c(
             xmin = -55.62471702, xmax = -55.57293653,
-            ymin = -11.63300767, ymax = -11.60607152, crs = 4326
-        ),
-        list(
+            ymin = -11.63300767, ymax = -11.60607152), crs = 4326
+        ))),
+        sf::st_as_sf(sf::st_as_sfc(sf::st_bbox(c(
             xmin = -55.29847023, xmax = -55.26194177,
-            ymin = -11.56743498, ymax = -11.55169416, crs = 4326
-        ),
-        list(
+            ymin = -11.56743498, ymax = -11.55169416), crs = 4326
+        ))),
+        sf::st_as_sf(sf::st_as_sfc(sf::st_bbox(c(
             xmin = -55.55720906, xmax = -55.54030539,
-            ymin = -11.75144257, ymax = -11.74521358, crs = 4326
-        )
+            ymin = -11.75144257, ymax = -11.74521358), crs = 4326
+        )))
     )
-    polygons_lst <- lapply(poly_lst,
-                           function(x) do.call(.sits_bbox_to_sf, x)
-    )
-    polygons_sf <- do.call(rbind, polygons_lst)
+
     polygons_sf[["id"]] <- seq(1, 3)
     polygons_sf[["label"]] <- c("a", "b", "c")
     polygons_bbox <- sf::st_bbox(polygons_sf)
@@ -289,7 +285,7 @@ test_that("Reading a SHP file from RASTER", {
         expected = c("a", "b", "c")
     )
 
-    temp_shp_no_label <- dplyr::select(temp_shp, -.data[["label"]])
+    temp_shp_no_label <- dplyr::select(temp_shp, -"label")
     points_shp_no_label <- sits_get_data(raster_cube,
                                     samples = temp_shp_no_label,
                                     pol_avg = TRUE,
@@ -303,7 +299,7 @@ test_that("Reading a SHP file from RASTER", {
         expected = "NoClass"
     )
 
-    temp_shp_label_attr <- dplyr::rename(temp_shp, label_2 = .data[["label"]])
+    temp_shp_label_attr <- dplyr::rename(temp_shp, label_2 = "label")
     points_shp_label_attr <- sits_get_data(raster_cube,
                                            samples = temp_shp_label_attr,
                                            pol_avg = TRUE,
@@ -338,8 +334,6 @@ test_that("Reading a SHP file from RASTER", {
 })
 
 test_that("Test reading shapefile from BDC", {
-
-
     # check "BDC_ACCESS_KEY" - mandatory one per user
     bdc_access_key <- Sys.getenv("BDC_ACCESS_KEY")
 
@@ -421,3 +415,91 @@ test_that("Reading metadata from CSV file", {
         "start_date", "end_date", "label"
     )))
 })
+
+test_that("Reading data from Classified data", {
+    # create a random forest model
+    rfor_model <- sits_train(samples_modis_ndvi, sits_rfor())
+    # create a data cube from local files
+    data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
+    cube <- sits_cube(
+        source = "BDC",
+        collection = "MOD13Q1-6",
+        data_dir = data_dir,
+        delim = "_",
+        parse_info = c("X1", "tile", "band", "date")
+    )
+    output_dir <- tempdir()
+    # classify a data cube
+    probs_cube <- sits_classify(
+        data = cube,
+        ml_model = rfor_model,
+        output_dir = output_dir
+    )
+    # smooth the probability cube using Bayesian statistics
+    bayes_cube <- sits_smooth(probs_cube, output_dir = output_dir)
+    # label the probability cube
+    label_cube <- sits_label_classification(bayes_cube, output_dir = output_dir)
+
+    # Using CSV
+    csv_raster_file <- system.file("extdata/samples/samples_sinop_crop.csv",
+                                   package = "sits"
+    )
+    points_poly <- sits_get_data(label_cube,
+                                 samples = csv_raster_file,
+                                 output_dir = tempdir()
+    )
+    expect_equal(
+        nrow(points_poly), nrow(read.csv(csv_raster_file))
+    )
+
+    expect_equal(
+        colnames(points_poly), c("longitude", "latitude",
+                                 "start_date", "end_date",
+                                 "label", "cube", "predicted")
+    )
+    # Using lat/long
+    samples <- tibble::tibble(longitude = -55.66738, latitude = -11.76990)
+
+    point_ndvi <- sits_get_data(label_cube, samples)
+    expect_equal(nrow(point_ndvi), 1)
+
+    expect_equal(
+        colnames(point_ndvi), c("longitude", "latitude",
+                                 "start_date", "end_date",
+                                 "label", "cube", "predicted")
+    )
+    # Using shp
+    polygons_sf <- rbind(
+        sf::st_as_sf(sf::st_as_sfc(sf::st_bbox(c(
+            xmin = -55.62471702, xmax = -55.57293653,
+            ymin = -11.63300767, ymax = -11.60607152), crs = 4326
+        ))),
+        sf::st_as_sf(sf::st_as_sfc(sf::st_bbox(c(
+            xmin = -55.29847023, xmax = -55.26194177,
+            ymin = -11.56743498, ymax = -11.55169416), crs = 4326
+        ))),
+        sf::st_as_sf(sf::st_as_sfc(sf::st_bbox(c(
+            xmin = -55.55720906, xmax = -55.54030539,
+            ymin = -11.75144257, ymax = -11.74521358), crs = 4326
+        )))
+    )
+
+    polygons_sf[["id"]] <- seq(1, 3)
+    polygons_sf[["label"]] <- c("a", "b", "c")
+    polygons_bbox <- sf::st_bbox(polygons_sf)
+
+    points_poly <- sits_get_data(label_cube,
+                                 samples = polygons_sf,
+                                 output_dir = tempdir()
+    )
+    expect_equal(nrow(points_poly), 90)
+
+    expect_equal(
+        colnames(points_poly), c("longitude", "latitude",
+                                 "start_date", "end_date",
+                                 "label", "cube", "predicted")
+    )
+    unlink(probs_cube$file_info[[1]]$path)
+    unlink(bayes_cube$file_info[[1]]$path)
+    unlink(label_cube$file_info[[1]]$path)
+})
