@@ -1,7 +1,7 @@
 test_that("SVM  - Formula logref", {
-    samples_mt_ndvi <- sits_select(samples_modis_4bands, bands = "NDVI")
+
     svm_model <- sits_train(
-        samples_mt_ndvi,
+        samples_modis_ndvi,
         sits_svm(
             formula = sits_formula_logref(),
             kernel = "radial",
@@ -11,22 +11,21 @@ test_that("SVM  - Formula logref", {
     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
     point_class <- sits_classify(
         data = point_ndvi,
-        ml_model = svm_model
+        ml_model = svm_model,
+        multicores = 1
     )
 
     expect_true(sits_labels(point_class) == "NoClass")
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_mt_ndvi)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
 
 test_that("SVM  - Formula logref - difference", {
-    samples_mt_2bands <- sits_select(samples_modis_4bands,
-        bands = c("NDVI", "EVI")
-    )
+
     svm_model <- sits_train(
-        samples_mt_2bands,
+        samples_modis_ndvi,
         ml_method = sits_svm(
             formula = sits_formula_logref(),
             kernel = "radial",
@@ -40,14 +39,14 @@ test_that("SVM  - Formula logref - difference", {
     )
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_mt_2bands)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 100)
 })
 
 test_that("SVM - Formula linear", {
-    samples_mt_ndvi <- sits_select(samples_modis_4bands, bands = "NDVI")
+
     svm_model <- sits_train(
-        samples_mt_ndvi,
+        samples_modis_ndvi,
         sits_svm(
             formula = sits_formula_linear(),
             kernel = "radial",
@@ -61,13 +60,13 @@ test_that("SVM - Formula linear", {
     )
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_mt_ndvi)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
 
 test_that("Random Forest", {
-    samples_mt_ndvi <- sits_select(samples_modis_4bands, bands = "NDVI")
-    rfor_model <- sits_train(samples_mt_ndvi, sits_rfor(num_trees = 200))
+
+    rfor_model <- sits_train(samples_modis_ndvi, sits_rfor(num_trees = 200))
     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
     point_class <- sits_classify(
         data = point_ndvi,
@@ -75,13 +74,16 @@ test_that("Random Forest", {
     )
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_mt_ndvi)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
+
+    exported_rf <- sits_model_export(rfor_model)
+    expect_s3_class(object = exported_rf, class = "randomForest")
 })
 
 test_that("Random Forest - Whittaker", {
-    samples_mt_ndvi <- sits_select(samples_modis_4bands, bands = "NDVI")
-    samples_mt_whit <- sits_filter(samples_mt_ndvi, filter = sits_whittaker())
+
+    samples_mt_whit <- sits_filter(samples_modis_ndvi, filter = sits_whittaker())
     rfor_model <- sits_train(samples_mt_whit, sits_rfor(num_trees = 200))
     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
     point_whit <- sits_filter(point_ndvi, filter = sits_whittaker())
@@ -91,13 +93,13 @@ test_that("Random Forest - Whittaker", {
     )
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_mt_ndvi)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
 
 test_that("Random Forest - SGolay", {
-    samples_mt_ndvi <- sits_select(samples_modis_4bands, bands = "NDVI")
-    samples_mt_sg <- sits_filter(samples_mt_ndvi, filter = sits_sgolay())
+
+    samples_mt_sg <- sits_filter(samples_modis_ndvi, filter = sits_sgolay())
     rfor_model <- sits_train(samples_mt_sg, sits_rfor(num_trees = 200))
     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
     point_sg <- sits_filter(point_ndvi, filter = sits_sgolay())
@@ -107,16 +109,14 @@ test_that("Random Forest - SGolay", {
     )
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_mt_ndvi)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
 
-
-
 test_that("XGBoost", {
-    samples_mt_ndvi <- sits_select(samples_modis_4bands, bands = "NDVI")
+
     model <- sits_train(
-        samples_mt_ndvi,
+        samples_modis_ndvi,
         sits_xgboost(
             nrounds = 10,
             verbose = FALSE
@@ -129,14 +129,13 @@ test_that("XGBoost", {
     )
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_mt_ndvi)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
 
-
 test_that("DL-MLP", {
     model <- sits_train(
-        sits_select(samples_modis_4bands, bands = "NDVI"),
+        samples_modis_ndvi,
         sits_mlp(
             layers = c(128, 128),
             dropout_rates = c(0.5, 0.4),
@@ -151,16 +150,16 @@ test_that("DL-MLP", {
     )
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_modis_4bands)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
 
 test_that("ResNet", {
-    samples_ndvi <- sits_select(samples_modis_4bands, bands = "NDVI")
+
 
     model <- tryCatch(
         {
-            sits_train(samples_ndvi, sits_resnet(epochs = 5))
+            sits_train(samples_modis_ndvi, sits_resnet(epochs = 5))
         },
         error = function(e) {
             return(NULL)
@@ -177,13 +176,12 @@ test_that("ResNet", {
     )
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_ndvi)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
 
 test_that("TempCNN model", {
-    model <- sits_train(
-        sits_select(samples_modis_4bands, bands = "NDVI"),
+    model <- sits_train(samples_modis_ndvi,
         sits_tempcnn(epochs = 5)
     )
 
@@ -197,13 +195,12 @@ test_that("TempCNN model", {
         )
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_modis_4bands)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
 
 test_that("LightTAE model", {
-    model <- sits_train(
-        sits_select(samples_modis_4bands, bands = "NDVI"),
+    model <- sits_train(samples_modis_ndvi,
         sits_lighttae(epochs = 5)
     )
     point_ndvi <- sits_select(point_mt_6bands, bands = "NDVI")
@@ -215,13 +212,12 @@ test_that("LightTAE model", {
         )
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_modis_4bands)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
 
 test_that("PSETAE model", {
-    model <- sits_train(
-        sits_select(samples_modis_4bands, bands = "NDVI"),
+    model <- sits_train(samples_modis_ndvi,
         sits_tae(epochs = 5)
     )
 
@@ -234,11 +230,14 @@ test_that("PSETAE model", {
         )
 
     expect_true(all(point_class$predicted[[1]]$class %in%
-        sits_labels(samples_modis_4bands)))
+        sits_labels(samples_modis_ndvi)))
     expect_true(nrow(sits_show_prediction(point_class)) == 17)
 })
 
-test_that("normalization", {
+test_that("normalization former version", {
+    #
+    # Old (yet supported) normalization
+    #
     stats <- .sits_ml_normalization_param(cerrado_2classes)
 
     norm1 <- .sits_ml_normalize_data(
@@ -267,3 +266,28 @@ test_that("normalization", {
     expect_equal(stats1[1, NDVI], stats3[1, NDVI], tolerance = 0.001)
     expect_equal(stats1[2, NDVI], stats3[2, NDVI], tolerance = 0.001)
 })
+
+test_that("normalization new version", {
+    #
+    # New normalization
+    #
+    stats <- .sits_stats(cerrado_2classes)
+
+    # In new version only predictors can be normalized
+    preds <- .predictors(cerrado_2classes)
+
+    # Now, 'norm1' is a normalized predictors
+    preds_norm <- .pred_normalize(preds, stats)
+
+    # From predictors, get feature values
+    values <- .pred_features(preds)
+    values_norm <- .pred_features(preds_norm)
+
+    # Normalized data should have minimum value between
+    #   0.0001 (inclusive) and abs(min(values))
+    expect_true(1e-4 <= min(values_norm) && min(values_norm) < abs(min(values)))
+
+    # Normalized data should have maximum value between
+    #   abs(max(values)) and 1.0 (inclusive)
+    expect_true(abs(max(values)) < max(values_norm) && max(values_norm) <= 1.0)
+})
