@@ -1,9 +1,5 @@
 test_that("One-year, multicore classification with ROI", {
-    samples_ndvi <- sits_select(samples_modis_4bands,
-        bands = c("NDVI")
-    )
-
-    rfor_model <- sits_train(samples_ndvi, sits_rfor(num_trees = 30))
+    rfor_model <- sits_train(samples_modis_ndvi, sits_rfor(num_trees = 30))
 
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
     sinop <- sits_cube(
@@ -11,30 +7,24 @@ test_that("One-year, multicore classification with ROI", {
         collection = "MOD13Q1-6",
         data_dir = data_dir,
         delim = "_",
-        parse_info = c("X1", "X2", "tile", "band", "date")
+        parse_info = c("X1", "tile", "band", "date")
     )
 
-    bbox <- sits_bbox(sinop)
+    bbox <- .bbox(sinop)
     bbox[["xmax"]] <- (bbox[["xmax"]] - bbox[["xmin"]]) / 2 + bbox[["xmin"]]
     bbox[["ymax"]] <- (bbox[["ymax"]] - bbox[["ymin"]]) / 2 + bbox[["ymin"]]
 
-
-    sinop_probs <- tryCatch(
-        {
-            suppressMessages(
-                sits_classify(
-                    data = sinop,
-                    ml_model = rfor_model,
-                    output_dir = tempdir(),
-                    roi = bbox,
-                    memsize = 4,
-                    multicores = 2
-                )
-            )
-        },
-        error = function(e) {
-            return(NULL)
-        }
+    sinop_probs <- .try({
+        sits_classify(
+            data = sinop,
+            ml_model = rfor_model,
+            output_dir = tempdir(),
+            roi = bbox,
+            memsize = 4,
+            multicores = 2
+        )
+    },
+    .default = NULL
     )
 
     if (purrr::is_null(sinop_probs)) {
@@ -66,11 +56,11 @@ test_that("Bbox in WGS 84", {
         collection = "MOD13Q1-6",
         data_dir = data_dir,
         delim = "_",
-        parse_info = c("X1", "X2", "tile", "band", "date")
+        parse_info = c("X1", "tile", "band", "date")
     )
 
-    bbox <- sits_bbox(sinop, wgs84 = TRUE)
-    expect_true(all(names(bbox) %in% c("xmin", "ymin", "xmax", "ymax")))
+    bbox <- sits_bbox(sinop, as_crs = "EPSG:4326")
+    expect_true(all(names(bbox) %in% c("xmin", "ymin", "xmax", "ymax", "crs")))
 })
 
 test_that("Functions that work with ROI", {
@@ -80,7 +70,7 @@ test_that("Functions that work with ROI", {
         collection = "MOD13Q1-6",
         data_dir = data_dir,
         delim = "_",
-        parse_info = c("X1", "X2", "tile", "band", "date")
+        parse_info = c("X1", "tile", "band", "date")
     )
     # create a roi
     roi <- sits_bbox(cube)
@@ -88,9 +78,9 @@ test_that("Functions that work with ROI", {
     roi[["ymax"]] <- (roi[["ymax"]] - roi[["ymin"]]) / 2 + roi[["ymin"]]
 
     # retrieve the bounding box for this ROI
-    bbox_1 <- .sits_roi_bbox(roi, cube)
+    bbox_1 <- .roi_bbox(roi, cube)
 
-    expect_true(length(.sits_bbox_intersect(bbox_1, cube)) == 4)
+    expect_true(length(.bbox_intersect(bbox_1, cube)) == 4)
 
     # read a set of lat long coordinates
     csv_file <- system.file("extdata/samples/samples_sinop_crop.csv",
@@ -103,16 +93,16 @@ test_that("Functions that work with ROI", {
         sf::st_as_sf(coords = c("longitude", "latitude"), crs = 4326)
 
     # read a bbox as an sf object
-    bbox_2 <- .sits_roi_bbox(sf_obj, cube)
-    expect_true(length(.sits_bbox_intersect(bbox_2, cube)) == 4)
+    bbox_2 <- .roi_bbox(sf_obj, cube)
+    expect_true(length(.bbox_intersect(bbox_2, cube)) == 4)
 
     # extract the bounding box from a set of lat/long points
     sf_bbox <- sf::st_bbox(sf_obj)
     names(sf_bbox) <- c("lon_min", "lat_min", "lon_max", "lat_max")
     class(sf_bbox) <- c("vector")
-    bbox_3 <- .sits_roi_bbox(sf_bbox, cube)
+    bbox_3 <- .roi_bbox(sf_bbox, cube)
 
-    expect_true(length(.sits_bbox_intersect(bbox_3, cube)) == 4)
+    expect_true(length(.bbox_intersect(bbox_3, cube)) == 4)
 })
 
 test_that("Internal functions in ROI", {
@@ -122,7 +112,7 @@ test_that("Internal functions in ROI", {
         collection = "MOD13Q1-6",
         data_dir = data_dir,
         delim = "_",
-        parse_info = c("X1", "X2", "tile", "band", "date")
+        parse_info = c("X1", "tile", "band", "date")
     )
     # create a roi
     roi <- sits_bbox(cube)
@@ -133,7 +123,7 @@ test_that("Internal functions in ROI", {
 
     roi_2size["xmax"] <- roi[["xmax"]] - 2 * x_size
     roi_2size["xmin"] <- roi[["xmin"]] - 2 * x_size
-    expect_null(.sits_bbox_intersect(roi_2size, cube))
+    expect_null(.bbox_intersection(.bbox(roi_2size), .bbox(cube)))
 
     bbox <- sits_bbox(cube)
     bbox[["xmax"]] <- bbox[["xmax"]] + x_size
@@ -141,16 +131,16 @@ test_that("Internal functions in ROI", {
     bbox[["ymax"]] <- bbox[["ymax"]] + x_size
     bbox[["ymin"]] <- bbox[["ymin"]] - x_size
 
-    int_bbox <- .sits_bbox_intersect(bbox, cube)
+    int_bbox <- .bbox_intersection(.bbox(bbox), .bbox(cube))
     expect_true(all(int_bbox == sits_bbox(cube)))
 
     bb <- sits_bbox(cube)
     bb[["xmin"]] <- bb[["xmin"]] + x_size / 4
     bb[["ymin"]] <- bb[["ymin"]] + x_size / 4
 
-    si <- .sits_raster_sub_image_from_bbox(bb, cube)
-    expect_equal(si[["first_row"]], 1)
-    expect_equal(si[["first_col"]], 64)
-    expect_equal(si[["nrows"]], 81)
+    si <- .raster_sub_image_from_bbox(bb, cube)
+    expect_equal(si[["col"]], 64)
+    expect_equal(si[["row"]], 1)
     expect_equal(si[["ncols"]], 191)
+    expect_equal(si[["nrows"]], 81)
 })
